@@ -1,5 +1,7 @@
 package OTRS::OPM::Maker::Utils::OTRS4;
 
+# ABSTRACT: helper functions for OTRS >= 4
+
 use strict;
 use warnings;
 
@@ -38,11 +40,17 @@ __END__
 
 =head1 NAME
 
-OTRS::OPM::Maker::Utils::OTRS4
+OTRS::OPM::Maker::Utils::OTRS4 - helper functions for OTRS >= 4
 
 =head1 VERSION
 
-version 1.4
+version 1.41
+
+=head1 METHODS
+
+=head2 packagesetup
+
+=head2 filecheck
 
 =head1 AUTHOR
 
